# Copyright (c) 2015 Hewlett-Packard Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from oslo_middleware import opts
from oslotest.base import BaseTestCase


class TestOptionDiscovery(BaseTestCase):

    def test_all(self):
        opts.list_opts()

    def test_sizelimit(self):
        opts.list_opts_sizelimit()

    def test_cors(self):
        opts.list_opts_cors()

    def test_ssl(self):
        opts.list_opts_ssl()
